pub enum FileName {
Real(PathBuf),
Virtual(Cow<'static, str>),
}Expand description
A FileName represents the name of a logical source code file, while retaining some context about whether that file is a real file on disk, or a “virtual” file, i.e. only exists in memory.
Variants
Implementations
Sourceimpl FileName
impl FileName
Sourcepub fn real<T: Into<PathBuf>>(name: T) -> FileName
pub fn real<T: Into<PathBuf>>(name: T) -> FileName
Creates a new FileName that is intended to represent a real file on disk.
Sourcepub fn virtual_<T: Into<Cow<'static, str>>>(name: T) -> FileName
pub fn virtual_<T: Into<Cow<'static, str>>>(name: T) -> FileName
Creates a new FileName that is intended to represent a virtual file in memory.
Sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Tries to return this filename as a &str, avoiding any allocations
This will only return None if the filename is a path which requires lossy conversion to unicode.
See to_string if you want an infallible conversion to a Rust string, albeit at the cost of an allocation