CaptureEmitter

Struct CaptureEmitter 

pub struct CaptureEmitter { /* private fields */ }
CaptureEmitter is used to capture diagnostics which are emitted, for later examination.

This is intended for use in testing, where it is desirable to emit diagnostics and write assertions about what was displayed to the user.

Implementations

Source

impl CaptureEmitter

pub fn new() -> Self

Create a new CaptureEmitter

pub fn captured(&self) -> String