DiagnosticsHandler

Struct DiagnosticsHandler 

pub struct DiagnosticsHandler { /* private fields */ }
DiagnosticsHandler acts as the nexus point for configuring and emitting diagnostics. It puts together many of the pieces provided by this crate to provide a useful and convenient interface for handling diagnostics throughout a compiler.

In order to construct a DiagnosticsHandler, you will need a CodeMap, an Emitter, and a DiagnosticsConfig describing how the handler should behave.

DiagnosticsHandler is a thread-safe structure, and is intended to be passed around freely as needed throughout your project.

Implementations

Source

impl DiagnosticsHandler

pub fn new( config: DiagnosticsConfig, codemap: Arc<CodeMap>, emitter: Arc<dyn Emitter>, ) -> Self

Create a new DiagnosticsHandler from the given DiagnosticsConfig, CodeMap, and Emitter implementation.

pub fn lookup_file_id(&self, filename: impl Into<FileName>) -> Option<SourceId>

Get the SourceId corresponding to the given filename

pub fn has_errors(&self) -> bool

Returns true if the DiagnosticsHandler has emitted any error diagnostics

pub fn abort_if_errors(&self)

Triggers a panic if the DiagnosticsHandler has emitted any error diagnostics

pub fn fatal(&self, err: impl ToString) -> FatalError

Emits an error message and produces a FatalError object which can be used to terminate execution immediately

pub fn error(&self, error: impl ToString)

Report an error diagnostic

pub fn warn(&self, warning: impl ToString)

Report a warning diagnostic

If warnings_as_errors is set, it produces an error diagnostic instead.

pub fn info(&self, message: impl ToString)

Emits an informational diagnostic

pub fn debug(&self, message: impl ToString)

Emits a debug diagnostic

pub fn note(&self, message: impl ToString)

Emits a note diagnostic

pub fn notice(&self, prefix: &str, message: impl ToString)

Prints a warning-like message with the given prefix

NOTE: This does not get promoted to an error if warnings-as-errors is set, as it is intended for informational purposes, not issues with the code being compiled

pub fn success(&self, prefix: &str, message: impl ToString)

Prints a success message with the given prefix

pub fn failed(&self, prefix: &str, message: impl ToString)

Prints an error message with the given prefix

pub fn diagnostic(&self, severity: Severity) -> InFlightDiagnostic<'_>

Starts building an InFlightDiagnostic for rich compiler diagnostics.

The caller is responsible for dropping/emitting the diagnostic using the InFlightDiagnostic API.

pub fn emit(&self, diagnostic: impl ToDiagnostic)

Emits the given diagnostic