pub struct Span<T: ?Sized> {
pub item: T,
/* private fields */
}Expand description
Span is used to wrap types which do not implement Spanned in a type that does.
Span is a bit special in that it is intended to be as transparent as possible, that means that it implements a variety of traits in a passthrough fashion, so that the span added to the underlying type does not change its behavior with regards to equality, hashing, ordering, etc. It does however have a Debug implementation that shows the span.
Fields
item: TThe underlying item wrapped by this Span
Implementations
Sourceimpl<T> Span<T>
impl<T> Span<T>
Sourcepub const fn new(span: SourceSpan, item: T) -> Self
pub const fn new(span: SourceSpan, item: T) -> Self
Construct a new Span from a SourceSpan and a [T]