pub type Label = Label<SourceId>;Aliased Type
pub struct Label {
pub style: LabelStyle,
pub file_id: SourceId,
pub range: Range<usize>,
pub message: String,
}Fields
style: LabelStyleThe style of the label.
file_id: SourceIdThe file that we are labelling.
range: Range<usize>The range in bytes we are going to include in the final snippet.
message: StringAn optional message to provide some additional information for the underlined code. These should not include line breaks.