Label

Type Alias Label 

pub type Label = Label<SourceId>;

Aliased Type

pub struct Label {
    pub style: LabelStyle,
    pub file_id: SourceId,
    pub range: Range<usize>,
    pub message: String,
}

Fields

style: LabelStyle

The style of the label.

file_id: SourceId

The file that we are labelling.

range: Range<usize>

The range in bytes we are going to include in the final snippet.

message: String

An optional message to provide some additional information for the underlined code. These should not include line breaks.